@@ -25,7 +25,7 @@
 
 
 # fit mixture to empirical (partial) correlations
-cor.fit.mixture <- function(r, MAXKAPPA=5000, fA.type=c("nonparametric", "uniform"))
+cor.fit.mixture <- function(r, MAXKAPPA=5000, fA.type=c("nonparametric", "uniform"), df=7)
 {
   if ( any(r > 1) || any(r < -1) )
       stop("Data out of range: input correlations must be in [-1; 1]")
@@ -36,7 +36,7 @@ cor.fit.mixture <- function(r, MAXKAPPA=5000, fA.type=c("nonparametric", "unifor
   {
      require("locfdr")
      
-     out <- locfdr(z.transform(r))
+     out <- locfdr(z.transform(r), df=df)
      eta0 <- as.double( out$fp0[3] ) # p0
      sigma <- as.double( out$fp0[2] ) # sig
      kappa <- 1/(sigma*sigma) + 2 # Fisher's rule
